function net = gen_complete(dd,nn,genpot1,genpot2)

% net = gen_complete(dd,nn,genpot1,genpot2)
%
% generates a complete graph with nn nodes.
% constructs an undirected graphical model with potentials
% generated by genpot1 (for single-site potentials) and genpot2 (pairwise ones).
%
% net.numnode     the number of variables in the graphical model.
% net.vars        is a shape where indices correspond to variables, sizes 
%                 are the sizes of the domains of the variables.
% net.phi1{nn,mm} is single-site potential at location nn,mm.
% net.phi2{nn,mm} is pairwise potential on edge nn-mm.
% net.graph       is adjacency matrix of undirected graph.
% net.edge        is list of edges in undirected graph.
%
% Example: the following generates complete binary graph with Gaussian weights.
% 
%       dd = 2; nn = 10;
%       genpot1 = @() exp(randn(dd,1)*.1);
%       genpot2 = @() exp(randn(dd,dd)*.5);
%       gen_complete(dd,10,genpot1,genpot2);

net = gen_random(dd,nn,1,genpot1,genpot2);
